@@ -15,13 +15,16 @@ ARGS:
 
 OPTIONS:
     --exec <COMMAND>          Change the execution command from the default.
-                              This is run when you hit the Enter on a path
+                              This is run when you hit the Enter on a path.
                               The default command is \"notepad\" on Windows, or \"cat\" on other platforms.
-    --starting-point <PATH>   Change the starting point from the default (\".\")
+    --log-file <PATH>         Log what the program is doing to the specified PATH.
+                              Log information is not output by default.
+    --starting-point <PATH>   Change the starting point from the default (\".\").
     --status-line <TYPE>      Change the information on the status line.
                               The possible values are \"absolute\", \"relative\", and \"none.\"
                               The default is \"absolute.\"
-    -h, --help                Prints help information
+    --no-gitignore            Do not respect .gitignore and search all paths including Git ignored paths.
+    -h, --help                Prints help information.
     -v, --version             Prints version info and exit
 ";
 
@@ -56,6 +59,8 @@ impl<A: Iterator<Item = OsString>> Parser<A> {
                 "--exec" => self.set_exec(None)?,
                 "--starting-point" => self.set_starting_point(None)?,
                 "--status-line" => self.set_status_line(None)?,
+                "--no-gitignore" => self.parsed_args.gitignore = false,
+                "--log-file" => self.set_log_file(None)?,
                 x if x.starts_with("--exec=") => {
                     if let Some((_, val)) = x.split_once('=') {
                         self.set_exec(Some(val))?;
@@ -71,6 +76,11 @@ impl<A: Iterator<Item = OsString>> Parser<A> {
                         self.set_status_line(Some(val))?;
                     }
                 }
+                x if x.starts_with("--log-file=") => {
+                    if let Some((_, val)) = x.split_once('=') {
+                        self.set_log_file(Some(val))?;
+                    }
+                }
                 x => {
                     if query.is_none() {
                         query = Some(x.to_string());
@@ -128,6 +138,11 @@ impl<A: Iterator<Item = OsString>> Parser<A> {
         Ok(())
     }
 
+    fn set_log_file(&mut self, value: Option<&str>) -> Result<()> {
+        self.parsed_args.log_file = Some(self.arg_value("--log-file", value)?);
+        Ok(())
+    }
+
     fn set_exec(&mut self, value: Option<&str>) -> Result<()> {
         self.parsed_args.exec = self.arg_value("--exec", value)?;
         Ok(())
@@ -188,8 +203,10 @@ impl TryFrom<String> for StatusLine {
 pub(crate) struct ParsedArgs {
     pub(crate) help: bool,
     pub(crate) version: bool,
+    pub(crate) gitignore: bool,
     pub(crate) starting_point: String,
     pub(crate) status_line: StatusLine,
+    pub(crate) log_file: Option<String>,
     pub(crate) query: String,
     pub(crate) exec: String,
 }
@@ -199,8 +216,10 @@ impl Default for ParsedArgs {
         Self {
             help: false,
             version: false,
+            gitignore: true,
             starting_point: String::from("."),
             status_line: StatusLine::Absolute,
+            log_file: None,
             query: String::from(""),
             exec: if cfg!(windows) {
                 String::from("notepad")
@@ -390,6 +409,72 @@ mod tests {
         );
     }
 
+    #[test]
+    fn parser_with_log_file() {
+        assert_eq!(
+            Parser::new(args!["program", "--log-file=./log.txt"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                log_file: Some(String::from("./log.txt")),
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--log-file", "./abc"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                log_file: Some(String::from("./abc")),
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--log-file==ok="])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                log_file: Some(String::from("=ok=")),
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--log-file", "xyz", "--help", "query"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                help: true,
+                query: String::from("query"),
+                log_file: Some(String::from("xyz")),
+                ..default!()
+            }
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--log-file"])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!("{}\n\n\"--log-file\" needs a value.", HELP),
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--log-file", "--"])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!("{}\n\n\"--log-file\" needs a value.", HELP),
+        );
+        assert_eq!(
+            Parser::new(args!["program", "--log-file="])
+                .parse()
+                .unwrap_err()
+                .message,
+            format!(
+                "{}\n\n\"--log-file\" needs a value. Empty string cannot be processed.",
+                HELP
+            ),
+        );
+    }
+
     #[test]
     fn parser_with_status_line() {
         assert_eq!(
@@ -479,6 +564,19 @@ mod tests {
         );
     }
 
+    #[test]
+    fn parser_with_no_gitignore() {
+        assert_eq!(
+            Parser::new(args!["program", "--no-gitignore"])
+                .parse()
+                .unwrap(),
+            ParsedArgs {
+                gitignore: false,
+                ..default!()
+            }
+        );
+    }
+
     #[test]
     fn parser_with_starting_point_disallow_option_like_value() {
         assert_eq!(
@@ -611,8 +709,10 @@ mod tests {
             ParsedArgs {
                 help: false,
                 version: false,
+                gitignore: true,
                 starting_point: String::from("."),
                 status_line: StatusLine::Absolute,
+                log_file: None,
                 query: String::from(""),
                 exec,
             }
