@@ -12,6 +12,7 @@ use crossterm::{
     style::{self, Attribute},
     terminal::{Clear, ClearType, EnterAlternateScreen, LeaveAlternateScreen},
 };
+use git2::Repository;
 
 use crate::args::{ParsedArgs, Parser, StatusLine, HELP};
 use crate::error::Result;
@@ -19,7 +20,7 @@ use crate::finder::Finder;
 use crate::matched_path::MatchedPath;
 use crate::starting_point::StartingPoint;
 use crate::terminal::{Terminal, TerminalEvent};
-use crate::Error;
+use crate::{logger, Error};
 
 pub fn safe_exit(code: i32, stdout: Stdout, stderr: Stderr) {
     let _ = stdout.lock().flush();
@@ -34,8 +35,13 @@ pub fn entrypoint<A: Iterator<Item = OsString>, W: Write>(
     mut event: impl TerminalEvent,
 ) -> Result<()> {
     let args = Parser::new(args).parse()?;
+    if let Some(ref path) = args.log_file {
+        logger::init(path)?;
+        log::debug!("Logger initialized!");
+    }
     if args.help {
         print_and_flush(stdout, HELP)?;
+        log::debug!("Show help and exit");
         return Ok(());
     }
     if args.version {
@@ -43,18 +49,45 @@ pub fn entrypoint<A: Iterator<Item = OsString>, W: Write>(
             stdout,
             &format!("{} {}\n", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION")),
         )?;
+        log::debug!("Show version and exit");
         return Ok(());
     }
 
+    let repo = if args.gitignore {
+        match Repository::discover(&args.starting_point) {
+            Ok(r) => Some(r),
+            Err(_) => {
+                log::info!(
+                    "The starting point `{}` is not a Git repository",
+                    &args.starting_point
+                );
+                None
+            }
+        }
+    } else {
+        None
+    };
     let (mut columns, mut rows) = terminal.size()?;
     let starting_point = StartingPoint::new(&args.starting_point)?;
     let mut query = args.query.clone();
-    let mut paths = find_paths(&starting_point, &query, paths_rows(&args, rows))?;
+    let mut paths = find_paths(
+        &starting_point,
+        &query,
+        paths_rows(&args, rows),
+        repo.as_ref(),
+    )?;
     let mut selection: u16 = 0;
     let mut state = State::QueryChanged;
     initialize_terminal(stdout, &terminal)?;
+    log::debug!(
+        "Initialized terminal! size=({:?}, {:?}), starting_point={:?}",
+        columns,
+        rows,
+        starting_point
+    );
 
     loop {
+        log::trace!("state={:?}", state);
         match state {
             State::QueryChanged => {
                 output_on_terminal(stdout, &args, &query, &paths[..], selection, columns, rows)?
@@ -72,6 +105,7 @@ pub fn entrypoint<A: Iterator<Item = OsString>, W: Write>(
 
         if event.poll(Duration::from_millis(300))? {
             let ev = event.read()?;
+            log::trace!("Event={:?}", ev);
             if should_just_exit(&ev) {
                 break;
             } else if let Event::Key(KeyEvent {
@@ -106,11 +140,21 @@ pub fn entrypoint<A: Iterator<Item = OsString>, W: Write>(
                 } else {
                     selection
                 };
-                paths = find_paths(&starting_point, &query, paths_rows(&args, rows))?;
+                paths = find_paths(
+                    &starting_point,
+                    &query,
+                    paths_rows(&args, rows),
+                    repo.as_ref(),
+                )?;
                 state = State::PathsChanged;
             }
         } else if let State::QueryChanged = state {
-            paths = find_paths(&starting_point, &query, paths_rows(&args, rows))?;
+            paths = find_paths(
+                &starting_point,
+                &query,
+                paths_rows(&args, rows),
+                repo.as_ref(),
+            )?;
             state = State::PathsChanged;
             selection = 0;
         }
@@ -125,6 +169,7 @@ pub fn entrypoint<A: Iterator<Item = OsString>, W: Write>(
     Ok(())
 }
 
+#[derive(Debug)]
 enum State<'a> {
     Ready,
     QueryChanged,
@@ -284,14 +329,19 @@ fn help_line(stdout: &mut impl Write, max_columns: usize) -> Result<()> {
     Ok(())
 }
 
-fn find_paths(starting_point: &StartingPoint, query: &str, limit: u16) -> Result<Vec<MatchedPath>> {
+fn find_paths(
+    starting_point: &StartingPoint,
+    query: &str,
+    limit: u16,
+    repo: Option<&Repository>,
+) -> Result<Vec<MatchedPath>> {
     let mut paths = Vec::with_capacity(100); // TODO: Tune this capacity later.
 
-    for path in Finder::new(starting_point, query)? {
+    for path in Finder::new(starting_point, query, repo)? {
         // TODO: Shouldn't we stop iteration when some paths returns Err?
         match path {
             Ok(path) => paths.push(path),
-            Err(_) => (), // TODO: Output failed paths to a log file.
+            Err(e) => log::error!("Failed to get the path: {}", e),
         }
     }
 
