@@ -11,7 +11,6 @@ pub type Result<T> = StdResult<T, Error>;
 #[derive(Debug)]
 pub enum ErrorKind {
     Args,
-    InsufficientQuery, // TODO: Delete
     InvalidUnicode,
     IO,
     Terminal,
@@ -50,15 +49,6 @@ impl Error {
         }
     }
 
-    pub fn insufficient_query(message: &str) -> Self {
-        Self {
-            message: message.to_string(),
-            kind: ErrorKind::InsufficientQuery,
-            source: None,
-            exit_code: FAILURE,
-        }
-    }
-
     pub fn invalid_unicode(message: &str) -> Self {
         Self {
             message: message.to_string(),
